pub struct Fts { /* private fields */ }Expand description
FTS query payload holding the query expression and match string.
query_string: a boolean / advanced query expressionmatch_string: a natural-language match string
Implementations
Sourceimpl Fts
impl Fts
Sourcepub fn set_query_string(&mut self, query: &str) -> Result<()>
pub fn set_query_string(&mut self, query: &str) -> Result<()>
Sets the boolean / advanced query expression.
Sourcepub fn set_match_string(&mut self, match_str: &str) -> Result<()>
pub fn set_match_string(&mut self, match_str: &str) -> Result<()>
Sets the natural-language match string.
Sourcepub fn query_string(&self) -> Option<String>
pub fn query_string(&self) -> Option<String>
Returns the query expression, or None if not set.
Sourcepub fn match_string(&self) -> Option<String>
pub fn match_string(&self) -> Option<String>
Returns the match string, or None if not set.