pub struct IvfRabitqQueryParams { /* private fields */ }Expand description
IVF RaBitQ-specific query parameters.
Implementations
Sourceimpl IvfRabitqQueryParams
impl IvfRabitqQueryParams
Sourcepub fn new(
nprobe: i32,
radius: f32,
is_linear: bool,
is_using_refiner: bool,
) -> Self
pub fn new( nprobe: i32, radius: f32, is_linear: bool, is_using_refiner: bool, ) -> Self
Creates new IVF RaBitQ query parameters.
Sourcepub fn set_nprobe(&mut self, nprobe: i32) -> Result<()>
pub fn set_nprobe(&mut self, nprobe: i32) -> Result<()>
Sets the number of probe clusters.
Sourcepub fn set_scale_factor(&mut self, scale_factor: f32) -> Result<()>
pub fn set_scale_factor(&mut self, scale_factor: f32) -> Result<()>
Sets the candidate expansion factor used by the refiner.
Sourcepub fn scale_factor(&self) -> f32
pub fn scale_factor(&self) -> f32
Returns the candidate expansion factor used by the refiner.